SunPy database
**************

The database submodule can be used to provide a local cache of the files and
records retrieved from various remote services. For an introduction to the
database see :ref:`database_guide`.


.. automodapi:: sunpy.database
    :no-inheritance-diagram:

Submodules
==========

.. automodapi:: sunpy.database.tables
    :no-inheritance-diagram:

.. automodapi:: sunpy.database.caching
    :no-inheritance-diagram:

.. automodapi:: sunpy.database.commands
    :no-inheritance-diagram:

.. automodapi:: sunpy.database.attrs
    :no-inheritance-diagram:
